thorn.django.models — Thorn 1.3.0 documentation

# thorn.django.models

- thorn.django.models

## thorn.django.models

Django models required to dispatch webhook events.

class `thorn.django.models.` `Subscriber`(id, uuid, event, url, user, hmac_secret, hmac_digest, content_type, created_at, updated_at)
  exception `DoesNotExist`
  exception `Subscriber.` `MultipleObjectsReturned`
  `Subscriber.` `get_content_type_display`(*moreargs, **morekwargs)
  `Subscriber.` `get_hmac_digest_display`(*moreargs, **morekwargs)
  `Subscriber.` `get_next_by_created_at`(*moreargs, **morekwargs)
  `Subscriber.` `get_next_by_updated_at`(*moreargs, **morekwargs)
  `Subscriber.` `get_previous_by_created_at`(*moreargs, **morekwargs)
  `Subscriber.` `get_previous_by_updated_at`(*moreargs, **morekwargs)
  `Subscriber.` `objects` = <thorn.django.managers.SubscriberManager object>
  `Subscriber.` `user`

    Accessor to the related object on the forward side of a many-to-one or one-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `child.parent` is a `ForwardManyToOneDescriptor` instance.

  `Subscriber.` `user_ident`()